#include <Wire.h>
#include <MPU6050.h>
#include <Servo.h>

MPU6050 mpu;
Servo servo; // Servo de direction
Servo frein; // Servo de frein

int16_t ax, ay, az;
float totalAccel = 0.0;
float accelThreshold = 15000;  // seuil de détection de mouvement (LSB brut)
bool mouvementDetecte = false;

void setup() {
  Serial.begin(9600);
  delay(1000); // laisser le port série se stabiliser

  Serial.println(">>> SETUP <<<");

  Wire.begin();           // SDA = A4, SCL = A5 sur Uno
  mpu.initialize();       // Initialisation MPU6050

  if (!mpu.testConnection()) {
    Serial.println("MPU6050 non détecté !");
    while (1); // Stop ici si erreur
  } else {
    Serial.println("MPU6050 connecté !");
  }

  // Initialisation des servos
  servo.attach(10);
  frein.attach(9);

  servo.write(180);
  Serial.println("MAX !");
  delay(1000);
  servo.write(50);
  Serial.println("MIN !");
  delay(1000);
  frein.write(0);
  Serial.println("Initialisation terminée !");
}

void loop() {
  // Lire les valeurs d'accélération
  mpu.getAcceleration(&ax, &ay, &az); //on accède aux données de l'accélération
  totalAccel = sqrt(ax * ax + ay * ay + az * az);  // on calcule l'accélération 

  Serial.print("Total Accel: ");
  Serial.println(totalAccel);

  // Détection de mouvement (seuil à ajuster selon tests)
  if (totalAccel > accelThreshold) {
    Serial.println(">>> MOUVEMENT DÉTECTÉ <<<");
    mouvementDetecte = true;
  }

  if (mouvementDetecte) {
    servo.write(70);  //on fait tourner le moteur
    delay(5000);
    servo.write(0);  // on arrete le moteur
    delay(3000);
    frein.write(180);  // on actionne le frein
    delay(10000);
    frein.write(0);

    mouvementDetecte = false; // Réinitialiser pour la prochaine détection
  }

  delay(200); // Boucle lente pour éviter trop de lectures
}
